"""
``djangorestframework`` (DRF) related configuration values. DRF uses a single dict to describe all of its options and configurations, so be careful not to overwrite this in your settings file.
"""

REST_FRAMEWORK = {
    "DEFAULT_RENDERER_CLASSES": (
        "djangorestframework_camel_case.render.CamelCaseJSONRenderer",
        "djangorestframework_camel_case.render.CamelCaseBrowsableAPIRenderer",
    ),
    "DEFAULT_PARSER_CLASSES": (
        "djangorestframework_camel_case.parser.CamelCaseFormParser",
        "djangorestframework_camel_case.parser.CamelCaseMultiPartParser",
        "djangorestframework_camel_case.parser.CamelCaseJSONParser",
    ),
}
"""
A DRF configuration dict. By default, it changes ``camelCase`` to ``snake_case`` in request data, and does the opposite for response data. This is to let you keep language-consistent styling in Python and JavaScript code.
"""



import time

from django.conf import settings


SESSION_EXPIRATION_SECONDS = getattr(settings, "SESSION_EXPIRATION_SECONDS", 3600)
SESSION_EXPIRATION_ACTIVITY_RESETS = getattr(
    settings, "SESSION_EXPIRATION_ACTIVITY_RESETS", True
)
SESSION_EXPIRATION_KEY = getattr(settings, "SESSION_EXPIRATION_KEY", "_last_active_at")


def has_session(request):
    return hasattr(request, "session") and not request.session.is_empty()


def session_expiration_middleware(get_response):
    """
    Middleware to expire Django sessions after a predetermined number of seconds has passed.
    """

    def middleware(request):
        if has_session(request):
            last_activity = request.session.get(SESSION_EXPIRATION_KEY)
            if (
                last_activity is None
                or time.time() - last_activity > SESSION_EXPIRATION_SECONDS
            ):
                request.session.flush()

        response = get_response(request)

        if has_session(request):
            last_activity = request.session.get(SESSION_EXPIRATION_KEY)
            if last_activity is None or SESSION_EXPIRATION_ACTIVITY_RESETS:
                request.session[SESSION_EXPIRATION_KEY] = time.time()

        return response

    return middleware



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['zygoat_django',
 'zygoat_django.management',
 'zygoat_django.management.commands',
 'zygoat_django.middleware',
 'zygoat_django.settings']

package_data = \
{'': ['*']}

install_requires = \
['django-environ>=0.4.5,<0.5.0',
 'django-redis>=4.12.1,<5.0.0',
 'django>=3.1.1,<4.0.0',
 'djangorestframework-camel-case>=1.2.0,<2.0.0',
 'djangorestframework>=3.11.1,<4.0.0',
 'importlib-metadata>=1.7.0,<2.0.0']

setup_kwargs = {
    'name': 'zygoat-django',
    'version': '0.3.0',
    'description': '',
    'long_description': None,
    'author': 'Mark Rawls',
    'author_email': 'markrawls96@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
